@@ -32,6 +32,18 @@ class KuryrTempestPlugin(plugins.TempestPlugin):
     def register_opts(self, conf):
         conf.register_opt(project_config.service_option,
                           group='service_available')
+        conf.register_opt(project_config.ports_pool_batch,
+                          group='vif_pool')
+        conf.register_opt(project_config.ports_pool_min,
+                          group='vif_pool')
+        conf.register_opt(project_config.ports_pool_max,
+                          group='vif_pool')
+        conf.register_opts(project_config.kuryr_k8s_opts,
+                           group='kuryr_kubernetes')
 
     def get_opt_lists(self):
-        return [('service_available', [project_config.service_option])]
+        return [('service_available', [project_config.service_option]),
+                ('kuryr_kubernetes', project_config.kuryr_k8s_opts),
+                ('vif_pool', [project_config.ports_pool_batch,
+                              project_config.ports_pool_min,
+                              project_config.ports_pool_max])]
