@@ -50,7 +50,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         ready = False
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 sg_id, _, ready = self.get_np_crd_info(
                     name=network_policy_name, namespace=namespace)
                 if sg_id and ready:
@@ -66,8 +66,6 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
                               egress_cidrs_should_exist=(),
                               ingress_cidrs_shouldnt_exist=(),
                               egress_cidrs_shouldnt_exist=()):
-        ingress_cidrs_found = set()
-        egress_cidrs_found = set()
         ingress_cidrs_should_exist = set(ingress_cidrs_should_exist)
         egress_cidrs_should_exist = set(egress_cidrs_should_exist)
         ingress_cidrs_shouldnt_exist = set(ingress_cidrs_shouldnt_exist)
@@ -77,6 +75,8 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
 
         while not rules_match and (time.time() - start) < TIMEOUT_PERIOD:
+            ingress_cidrs_found = set()
+            egress_cidrs_found = set()
             sg_rules = self.get_sg_rules_for_np(namespace, np)
 
             for rule in sg_rules:
@@ -85,17 +85,18 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
                 elif rule['direction'] == 'egress':
                     egress_cidrs_found.add(rule['remote_ip_prefix'])
 
-                if (ingress_cidrs_should_exist.issubset(ingress_cidrs_found)
-                    and (not ingress_cidrs_shouldnt_exist
-                         or not ingress_cidrs_shouldnt_exist.issubset(
-                                ingress_cidrs_found))
-                    and egress_cidrs_should_exist.issubset(egress_cidrs_found)
-                    and (not egress_cidrs_shouldnt_exist
-                         or not egress_cidrs_shouldnt_exist.issubset(
-                                egress_cidrs_found))):
-                    rules_match = True
-                else:
-                    time.sleep(10)
+            if (ingress_cidrs_should_exist.issubset(ingress_cidrs_found)
+                and (not ingress_cidrs_shouldnt_exist
+                     or not ingress_cidrs_shouldnt_exist.issubset(
+                            ingress_cidrs_found))
+                and egress_cidrs_should_exist.issubset(egress_cidrs_found)
+                and (not egress_cidrs_shouldnt_exist
+                     or not egress_cidrs_shouldnt_exist.issubset(
+                            egress_cidrs_found))):
+                rules_match = True
+
+            time.sleep(consts.NP_CHECK_SLEEP_TIME)
+
         if not rules_match:
             msg = 'Timed out waiting sg rules for np %s to match' % np
             raise lib_exc.TimeoutException(msg)
@@ -123,7 +124,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 sg_id, _, ready = self.get_np_crd_info(
                     network_policy_name, namespace=namespace_name)
                 if sg_id and ready:
@@ -148,6 +149,9 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
     def test_ipblock_network_policy_allow_except(self):
         namespace_name, namespace = self.create_namespace()
         self.addCleanup(self.delete_namespace, namespace_name)
+        pod_name, pod = self.create_pod(namespace=namespace_name)
+        self.addCleanup(self.delete_pod, pod_name, pod,
+                        namespace=namespace_name)
 
         if CONF.kuryr_kubernetes.kuryrnetworks:
             cidr = self.get_kuryr_network_crds(
@@ -202,7 +206,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 sg_id, _, _ = self.get_np_crd_info(network_policy_name,
                                                    namespace=namespace_name)
                 if sg_id:
@@ -243,7 +247,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 self.get_np_crd_info(network_policy_name,
                                      namespace=namespace_name)
             except kubernetes.client.rest.ApiException as e:
@@ -273,7 +277,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 sg_id, _, _ = self.get_np_crd_info(network_policy_name)
                 if sg_id:
                     break
@@ -287,7 +291,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         self.delete_network_policy(network_policy_name)
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
-            time.sleep(1)
+            time.sleep(consts.NP_CHECK_SLEEP_TIME)
             if network_policy_name in self.list_network_policies():
                 continue
             try:
@@ -316,7 +320,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 _, crd_pod_selector, _ = self.get_np_crd_info(
                     network_policy_name)
                 if crd_pod_selector:
@@ -337,7 +341,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 _, crd_pod_selector, _ = self.get_np_crd_info(
                     network_policy_name)
                 labels = crd_pod_selector.get('matchLabels')
@@ -364,7 +368,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 sg_id, _, _ = self.get_np_crd_info(network_policy_name,
                                                    namespace=ns_name)
                 if sg_id:
@@ -380,7 +384,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         self.delete_namespace(ns_name)
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
-            time.sleep(1)
+            time.sleep(consts.NP_CHECK_SLEEP_TIME)
             if network_policy_name in self.list_network_policies(
                     namespace=ns_name):
                 continue
@@ -394,7 +398,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
             sg_ids_after = [sg['id'] for sg in sgs_after]
             if sg_id not in sg_ids_after:
                 break
-            time.sleep(1)
+            time.sleep(consts.NP_CHECK_SLEEP_TIME)
         if time.time() - start >= TIMEOUT_PERIOD:
             raise lib_exc.TimeoutException('Sec group ID still exists')
 
@@ -412,7 +416,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
             try:
-                time.sleep(1)
+                time.sleep(consts.NP_CHECK_SLEEP_TIME)
                 sg_id, _, _ = self.get_np_crd_info(network_policy_name,
                                                    namespace=ns_name)
                 if sg_id:
@@ -426,7 +430,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
         self.delete_network_policy(network_policy_name, namespace=ns_name)
         start = time.time()
         while time.time() - start < TIMEOUT_PERIOD:
-            time.sleep(1)
+            time.sleep(consts.NP_CHECK_SLEEP_TIME)
             if network_policy_name in self.list_network_policies(
                     namespace=ns_name):
                 continue
@@ -440,7 +444,7 @@ class TestNetworkPolicyScenario(base.BaseKuryrScenarioTest,
             sg_ids_after = [sg['id'] for sg in sgs_after]
             if sg_id not in sg_ids_after:
                 break
-            time.sleep(1)
+            time.sleep(consts.NP_CHECK_SLEEP_TIME)
         if time.time() - start >= TIMEOUT_PERIOD:
             raise lib_exc.TimeoutException('Sec group ID still exists')
 
