@@ -19,5 +19,17 @@ POD_AFFINITY = {'requiredDuringSchedulingIgnoredDuringExecution': [
         'topologyKey': 'kubernetes.io/hostname'}]}
 TIME_TO_APPLY_SGS = 30
 POD_STATUS_RETRIES = 240
+POD_CHECK_TIMEOUT = 240
+POD_CHECK_SLEEP_TIME = 5
+NP_CHECK_SLEEP_TIME = 10
 NS_TIMEOUT = 600
 LB_TIMEOUT = 1200
+LB_RECONCILE_TIMEOUT = 600
+REPETITIONS_PER_BACKEND = 10
+KURYR_RESOURCE_CHECK_TIMEOUT = 300
+KURYR_PORT_CRD_PLURAL = 'kuryrports'
+KURYR_LOAD_BALANCER_CRD_PLURAL = 'kuryrloadbalancers'
+KURYR_NETWORK_POLICY_CRD_PLURAL = 'kuryrnetworkpolicies'
+K8s_ANNOTATION_PROJECT = 'openstack.org/kuryr-project'
+LOADBALANCER = 'loadbalancer'
+LISTENER = 'listeners'
